The NQ-Open task, introduced by Lee et.al. 2019, is an open domain question
answering benchmark that is derived from Natural Questions. The goal is to
predict an English answer string for an input English question. All questions
can be answered using the contents of English Wikipedia.
